@@ -1,5 +1,5 @@
 package PAUSE::Packages;
-$PAUSE::Packages::VERSION = '0.12';
+$PAUSE::Packages::VERSION = '0.13';
 use 5.10.0;
 use autodie qw(open);
 
@@ -11,7 +11,7 @@ use File::HomeDir;
 use File::Spec::Functions 'catfile';
 use HTTP::Date qw(time2str);
 use HTTP::Tiny;
-use JSON;
+use JSON::MaybeXS;
 use PAUSE::Packages::Module;
 use PAUSE::Packages::Release;
 use Safe::Isa;
