@@ -1,11 +1,11 @@
 package PAUSE::Packages::ReleaseIterator;
-$PAUSE::Packages::ReleaseIterator::VERSION = '0.12';
+$PAUSE::Packages::ReleaseIterator::VERSION = '0.13';
 use 5.10.0;
 use Moo;
 use PAUSE::Packages;
 use PAUSE::Packages::Release;
 use PAUSE::Packages::Module;
-use JSON;
+use JSON::MaybeXS;
 use autodie;
 use feature 'state';
 
